import React from 'react'

import { DropdownButton, MenuItem } from 'react-bootstrap'

export default class SubtitlesButton extends React.Component {
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
  }
  handleClick(e, url) {
    e.preventDefault();
    if (this.props.fetching) { return }

    // Refresh the subtitles
    this.props.refreshSubtitles(this.props.type, this.props.resourceID, this.props.season, this.props.episode);
  }
  render() {
    // If there is no URL, the resource is not in polochon, we won't be able to download subtitles
    if (this.props.url === "") {
      return null;
    }

    // Build the button
    const entries = buildMenuItems(this.props.subtitles);
    let btnSize = "small";
    if (this.props.xs) {
      btnSize = "xsmall";
    }

    return (
      <DropdownButton bsStyle="success" bsSize={btnSize} title="Subtitles" id="download-subtitles-button" dropup>
        {entries.map(function(e, index) {
          switch (e.type) {
            case 'action':
              return (
                <MenuItem key={index} onClick={(event) => this.handleClick(event, e.url)}>
                  {this.props.fetching ||
                      <span>
                        <i className="fa fa-refresh">
                        </i> Refresh
                      </span>
                  }
                  {this.props.fetching &&
                      <span>
                        <i className="fa fa-spin fa-refresh">
                        </i> Refreshing
                      </span>
                  }
                </MenuItem>
              );
            case 'divider':
              return (
                <MenuItem key={index} divider></MenuItem>
              );
            case 'entry':
              return (
                <MenuItem key={index} href={e.url}>
                  <i className="fa fa-download"></i>     {e.lang}
                </MenuItem>
              );
          }
        }, this)}
      </DropdownButton>
    );
  }
}

function buildMenuItems(subtitles) {
  // Build the array of entries
  let entries = [];

  // Push the refresh button
  entries.push({
    type: "action",
    value: "Refresh",
  });

  // If there is no subtitles, stop here
  if (subtitles == undefined) {
    return entries;
  }

  // Push the divider
  entries.push({ type: "divider" });
  // Push the subtitles
  for (let sub of subtitles) {
    entries.push({
      type: "entry",
      // Take only the last part of fr_FR
      lang: sub.get('language').split("_")[1],
      url: sub.get('url'),
    });
  }

  return entries;
}
