import { OrderedMap, Map, fromJS } from 'immutable'

const defaultState = Map({
  loading: false,
  movies: OrderedMap(),
  filter: "",
  selectedImdbId: "",
  lastFetchUrl: "",
  exploreOptions: Map(),
});

export default function movieStore(state = defaultState, action) {
  switch (action.type) {
    case 'MOVIE_LIST_FETCH_PENDING':
      return state.set('loading', true);
    case 'MOVIE_LIST_FETCH_FULFILLED':

      let movies = Map();
      action.payload.response.data.map(function (movie) {
        movie.fetchingDetails = false;
        movie.fetchingSubtitles = false;
        movies = movies.set(movie.imdb_id, fromJS(movie));
      })

      // Select the first movie if the list is not empty
      let selectedImdbId = "";
      if (movies.size > 0) {
        // Sort by year
        movies = movies.sort((a,b) => b.get('year') - a.get('year'));
        selectedImdbId = movies.first().get('imdb_id');
      }

      return state.delete('movies').merge(Map({
        movies: movies,
        filter: "",
        loading: false,
        selectedImdbId: selectedImdbId,
      }))
    case 'MOVIE_GET_DETAILS_PENDING':
      return state.setIn(['movies', action.payload.main.imdbId, 'fetchingDetails'], true);
    case 'MOVIE_GET_DETAILS_FULFILLED':
      let movie = action.payload.response.data;
      movie.fetchingDetails = false;
      movie.fetchingSubtitles = false;
      return state.setIn(['movies', movie.imdb_id], fromJS(movie));
    case 'MOVIE_UPDATE_STORE_WISHLIST':
      return state.setIn(['movies', action.payload.imdbId, 'wishlisted'], action.payload.wishlisted);
    case 'MOVIE_GET_EXPLORE_OPTIONS_FULFILLED':
      return state.set('exploreOptions', fromJS(action.payload.response.data));
    case 'UPDATE_LAST_MOVIE_FETCH_URL':
      return state.set('lastFetchUrl', action.payload.url);
    case 'MOVIE_SUBTITLES_UPDATE_PENDING':
      return state.setIn(['movies', action.payload.main.imdbId, 'fetchingSubtitles'], true);
    case 'MOVIE_SUBTITLES_UPDATE_FULFILLED':
      return state.setIn(['movies', action.payload.main.imdbId, 'fetchingSubtitles'], false).setIn(['movies', action.payload.main.imdbId, 'subtitles'], fromJS(action.payload.data.response));
    case 'SELECT_MOVIE':
      return state.set('selectedImdbId', action.payload.imdbId);
    case 'MOVIE_UPDATE_FILTER':
      return state.set('filter', action.payload.filter);
    default:
      return state
  }
}
