import { OrderedMap, Map, fromJS } from 'immutable'

const defaultState = Map({
  loading: false,
  shows: OrderedMap(),
  filter: "",
  selectedImdbId: "",
  lastFetchUrl: "",
  exploreOptions: Map(),
});

export default function showsStore(state = defaultState, action) {
  switch (action.type) {
    case 'SHOW_LIST_FETCH_PENDING':
      return state.set('loading', true);
    case 'SHOW_LIST_FETCH_FULFILLED':
      let shows = Map();
      action.payload.response.data.map(function (show) {
        show.fetchingDetails = false;
        show.fetchingSubtitles = false;
        shows = shows.set(show.imdb_id, fromJS(show));
      })

      let selectedImdbId = "";
      if (shows.size > 0) {
        // Sort by year
        shows = shows.sort((a,b) => b.get('year') - a.get('year'));
        selectedImdbId = shows.first().get('imdb_id');
      }

      return state.delete('shows').merge(Map({
        shows: shows,
        filter: "",
        loading: false,
        selectedImdbId: selectedImdbId,
      }))
    case 'SHOW_GET_DETAILS_PENDING':
      return state.setIn(['shows', action.payload.main.imdbId, 'fetchingDetails'], true);
    case 'SHOW_GET_DETAILS_FULFILLED':
      let show = action.payload.response.data;
      show.fetchingDetails = false;
      show.fetchingSubtitles = false;
      return state.setIn(['shows', show.imdb_id], fromJS(show));
    case 'SHOW_GET_EXPLORE_OPTIONS_FULFILLED':
      return state.set('exploreOptions', fromJS(action.payload.response.data));
    case 'SHOW_UPDATE_STORE_WISHLIST':
      let season = action.payload.season;
      let episode = action.payload.episode;
      if (action.payload.wishlisted) {
        if (season === null) {
          season = 0;
        }
        if (episode === null) {
          episode = 0;
        }
      }

      return state.mergeIn(['shows', action.payload.imdbId], Map({
        tracked_season: season,
        tracked_episode: episode,
      }));
    case 'UPDATE_LAST_SHOWS_FETCH_URL':
      return state.set('lastFetchUrl', action.payload.url);
    case 'SELECT_SHOW':
      return state.set('selectedImdbId', action.payload.imdbId);
    case 'SHOWS_UPDATE_FILTER':
      return state.set('filter', action.payload.filter);
    default:
      return state
  }
}
